@@ -45,6 +45,7 @@ class StockHistoricalDataClient(RESTClient):
         api_key: Optional[str] = None,
         secret_key: Optional[str] = None,
         oauth_token: Optional[str] = None,
+        use_basic_auth: bool = False,
         raw_data: bool = False,
         url_override: Optional[str] = None,
     ) -> None:
@@ -55,6 +56,7 @@ class StockHistoricalDataClient(RESTClient):
             api_key (Optional[str], optional): Alpaca API key. Defaults to None.
             secret_key (Optional[str], optional): Alpaca API secret key. Defaults to None.
             oauth_token (Optional[str]): The oauth token if authenticating via OAuth. Defaults to None.
+            use_basic_auth (bool, optional): If true, API requests will use basic authorization headers.
             raw_data (bool, optional): If true, API responses will not be wrapped and raw responses will be returned from
               methods. Defaults to False. This has not been implemented yet.
             url_override (Optional[str], optional): If specified allows you to override the base url the client points
@@ -64,6 +66,7 @@ class StockHistoricalDataClient(RESTClient):
             api_key=api_key,
             secret_key=secret_key,
             oauth_token=oauth_token,
+            use_basic_auth=use_basic_auth,
             api_version="v2",
             base_url=url_override if url_override is not None else BaseURL.DATA,
             sandbox=False,
