@@ -1,5 +1,6 @@
 from uuid import UUID
 from pydantic import parse_obj_as
+import json
 
 from alpaca.common import RawData
 from alpaca.common.utils import validate_uuid_id_param, validate_symbol_or_asset_id
@@ -31,6 +32,7 @@ from alpaca.trading.models import (
     Calendar,
     TradeAccount,
     CorporateActionAnnouncement,
+    AccountConfiguration,
 )
 
 
@@ -153,7 +155,9 @@ class TradingClient(RESTClient):
         Returns:
             alpaca.trading.models.Order: The queried order.
         """
-        response = self.get(f"/orders/{client_id}")
+        params = {"client_order_id": client_id}
+
+        response = self.get(f"/orders:by_client_order_id", params)
 
         if self._use_raw_data:
             return response
@@ -417,6 +421,40 @@ class TradingClient(RESTClient):
 
         return TradeAccount(**response)
 
+    def get_account_configurations(self) -> Union[AccountConfiguration, RawData]:
+        """
+        Returns account configuration details. Contains information like shorting, margin multiplier
+        trader confirmation emails, and Pattern Day Trading (PDT) checks.
+
+        Returns:
+            alpaca.broker.models.AccountConfiguration: The account configuration details
+        """
+        response = self.get("/account/configurations")
+
+        if self._use_raw_data:
+            return response
+
+        return AccountConfiguration(**response)
+
+    def set_account_configurations(
+        self, account_configurations: AccountConfiguration
+    ) -> Union[AccountConfiguration, RawData]:
+        """
+        Returns account configuration details. Contains information like shorting, margin multiplier
+        trader confirmation emails, and Pattern Day Trading (PDT) checks.
+
+        Returns:
+            alpaca.broker.models.TradeAccountConfiguration: The account configuration details
+        """
+        response = self.patch(
+            "/account/configurations", data=account_configurations.dict()
+        )
+
+        if self._use_raw_data:
+            return response
+
+        return AccountConfiguration(**json.loads(response))
+
     # ############################## WATCHLIST ################################# #
 
     def get_watchlists(
@@ -579,7 +617,7 @@ class TradingClient(RESTClient):
 
     # ############################## CORPORATE ACTIONS ################################# #
 
-    def get_corporate_annoucements(
+    def get_corporate_announcements(
         self, filter: GetCorporateAnnouncementsRequest
     ) -> Union[List[CorporateActionAnnouncement], RawData]:
         """
@@ -601,7 +639,7 @@ class TradingClient(RESTClient):
 
         return parse_obj_as(List[CorporateActionAnnouncement], response)
 
-    def get_corporate_announcment_by_id(
+    def get_corporate_announcement_by_id(
         self, corporate_announcment_id: Union[UUID, str]
     ) -> Union[CorporateActionAnnouncement, RawData]:
         """
